@@ -352,16 +352,16 @@ function(){
     rp.radiogroup(panel = my.panel, variable= exercisetype,
                   vals = c("European", "American"), 
                   action = my.redraw, title = "Exercise style")
-    rp.textentry(panel=my.panel,variable=FV,action=my.redraw,title="Face value      ",initval=100)
-    rp.textentry(panel=my.panel,variable=strike,action=my.redraw,title="Strike price    ",initval=80)
-    #rp.textentry(panel=my.panel,variable=Time,action=my.redraw,title="Time               ",initval=0.25)
-    #rp.textentry(panel=my.panel,variable=sigma,action=my.redraw,title="Volatility         ",initval=0.25)
-    rp.textentry(panel=my.panel,variable=r0,action=my.redraw,title="Rate (initial)   ",initval=5.0)
-    rp.textentry(panel=my.panel,variable=coupon,action=my.redraw,title="Coupon          ",initval=0.0)
-    rp.textentry(panel=my.panel,variable=u,action=my.redraw,title="up per step     ",initval=1.1)
-    rp.textentry(panel=my.panel,variable=d,action=my.redraw,title="down per step",initval=0.9)
-    rp.textentry(panel=my.panel,variable=q,action=my.redraw,title="q per step       ",initval=0.5)
-    #rp.textentry(panel=my.panel,variable=Div,action=my.redraw,title="Dividend rate ",initval=0)
+    rp.textentry(panel=my.panel,variable=FV,action=my.redraw,labels="Face value      ",initval=100)
+    rp.textentry(panel=my.panel,variable=strike,action=my.redraw,labels="Strike price    ",initval=80)
+    #rp.textentry(panel=my.panel,variable=Time,action=my.redraw,labels="Time               ",initval=0.25)
+    #rp.textentry(panel=my.panel,variable=sigma,action=my.redraw,labels="Volatility         ",initval=0.25)
+    rp.textentry(panel=my.panel,variable=r0,action=my.redraw,labels="Rate (initial)   ",initval=5.0)
+    rp.textentry(panel=my.panel,variable=coupon,action=my.redraw,labels="Coupon          ",initval=0.0)
+    rp.textentry(panel=my.panel,variable=u,action=my.redraw,labels="up per step     ",initval=1.1)
+    rp.textentry(panel=my.panel,variable=d,action=my.redraw,labels="down per step",initval=0.9)
+    rp.textentry(panel=my.panel,variable=q,action=my.redraw,labels="q per step       ",initval=0.5)
+    #rp.textentry(panel=my.panel,variable=Div,action=my.redraw,labels="Dividend rate ",initval=0)
     #rp.doublebutton(panel = my.panel, showvalue=TRUE, variable= ratesteps, step = 1, range = c(1, 16),initval=10,
     #                title = "Rate tree steps", action = my.redraw)
     rp.doublebutton(panel = my.panel, showvalue=TRUE, variable= bondmaturity, step = 1, range = c(1, 15),initval=10,
