@@ -22,9 +22,9 @@ function(){
   }
   
   my.panel <- rp.control(title = "Cash price of a T Bond Futures")
-  rp.textentry(panel=my.panel,variable=quoted,title="Quoted Price:",action=my.redraw,initval=102)
-  rp.textentry(panel=my.panel,variable=convfac,title="Conv. Factor:",action=my.redraw,initval=1.08)
-  rp.textentry(panel=my.panel,variable=accint,title="Acc. Interest: ",action=my.redraw,initval=4)
+  rp.textentry(panel=my.panel,variable=quoted,labels="Quoted Price:",action=my.redraw,initval=102)
+  rp.textentry(panel=my.panel,variable=convfac,labels="Conv. Factor:",action=my.redraw,initval=1.08)
+  rp.textentry(panel=my.panel,variable=accint,labels="Acc. Interest: ",action=my.redraw,initval=4)
   rp.tkrplot(panel = my.panel, pos="bottom",name = my.tkrplot, plotfun = my.draw)
   #rp.do(my.panel, my.draw)
   
